ArgbSliceU32

Struct ArgbSliceU32 

pub struct ArgbSliceU32<'a> { /* private fields */ }
Container for a slice of contiguous [ARGB ARGB ...] data.

The platform endianness of the data is irrelevant: A is the highest byte and B is the lowest.

Implementations

Source

impl<'a> ArgbSliceU32<'a>

pub fn new(data: &'a [u32], dimensions: (usize, usize)) -> Self

Creates a new instance given the data slice and dimensions.

Panics

May panic if the given sizes are not multiples of 2, or if the slice length mismatches the given dimensions.