BgrSliceU8

Struct BgrSliceU8 

pub struct BgrSliceU8<'a> { /* private fields */ }
Container for a slice of contiguous [B G R B G R ...] data.

Implementations

Source

impl<'a> BgrSliceU8<'a>

pub fn new(data: &'a [u8], dimensions: (usize, usize)) -> Self

Creates a new instance given the byte slice and dimensions.

Panics

May panic if the given sizes are not multiples of 2, or if the slice length mismatches the given dimensions.