BgraSliceU32

Struct BgraSliceU32 

pub struct BgraSliceU32<'a> { /* private fields */ }
Container for a slice of contiguous [BGRA BGRA ...] data.

The platform endianness of the data is irrelevant: B is the highest byte and A is the lowest.

Implementations

Source

impl<'a> BgraSliceU32<'a>

pub fn new(data: &'a [u32], dimensions: (usize, usize)) -> Self

Creates a new instance given the data slice and dimensions.

Panics

May panic if the given sizes are not multiples of 2, or if the slice length mismatches the given dimensions.