RgbSliceU8

Struct RgbSliceU8 

pub struct RgbSliceU8<'a> { /* private fields */ }
Container for a slice of contiguous [R G B R G B ...] data.

This is the preferred format for reading data, for use with _rgb8 methods.

Implementations

Source

impl<'a> RgbSliceU8<'a>

pub fn new(data: &'a [u8], dimensions: (usize, usize)) -> Self

Creates a new instance given the byte slice and dimensions.

Panics

May panic if the given sizes are not multiples of 2, or if the slice length mismatches the given dimensions.