RgbaSliceU32

Struct RgbaSliceU32 

pub struct RgbaSliceU32<'a> { /* private fields */ }
Container for a slice of contiguous [RGBA RGBA ...] data.

The platform endianness of the data is irrelevant: R is the highest byte and A is the lowest.

Implementations

Source

impl<'a> RgbaSliceU32<'a>

pub fn new(data: &'a [u32], dimensions: (usize, usize)) -> Self

Creates a new instance given the data slice and dimensions.

Panics

May panic if the given sizes are not multiples of 2, or if the slice length mismatches the given dimensions.