RGB8Source

Trait RGB8Source 

pub trait RGB8Source: RGBSource {
    // Required methods
    fn dimensions_padded(&self) -> (usize, usize);
    fn rgb8_data(&self) -> &[u8] ;
}
Source of RGB8 data for fast pixel access.

This is the “fast” trait for RGB sources. If you can expose continuous pixels slices with RGB8 data you might (eventually) be rewarded with SIMD conversion.

Required Methods

fn dimensions_padded(&self) -> (usize, usize)

Returns padded dimensions of the underlying slice.

For example, the data might have a display format of 100x100, but the underlying RGB8 array is of size 128x100.

fn rgb8_data(&self) -> &[u8]

Slice of RGB8 data, with given padding.

Implementors